@@ -43,12 +43,7 @@
 ;;; Requires
 
 (require 'latin-unity-vars)
-(require 'latin-unity-latin7)		; define iso-8859-13
-;; uncomment to add support for ISO 8859/14
-;(require 'latin-unity-latin8)		; define iso-8859-14
-(require 'latin-unity-latin9)		; define iso-8859-15
-;; uncomment to add support for ISO 8859/16
-;(require 'latin-unity-latin10)		; define iso-8859-16
+
 (if (or (fboundp 'character-to-unicode)	; XEmacs  post-21.5.5
 	(fboundp 'char-to-ucs))		; Mule-UCS already loaded
     (require 'latin-unity-tables "latin-unity-utils")
@@ -556,11 +551,14 @@ to the Mule detection mechanism.  This could result in corruption.  So avoid
 setting `buffer-file-coding-system' to nil or 'no-conversion or 'binary.
 
 This function is intended for use as a `write-region-pre-hook'.  It does
-nothing except return nil if `write-region' handlers are inhibited."
+nothing except return nil if `write-region' handlers are inhibited, or if
+BEGIN is a string (to support the corresponding \"kludgy feature\" of
+`write-region')."
 
   ;; don't do anything if we're in a `write-region' handler
   ;; #### is nil the right return value if we are?
-  (if (eq inhibit-file-name-operation 'write-region)
+  ;; Bypass also on `write-region's "klugdy feature" where BEGIN is a string
+  (if (or (eq inhibit-file-name-operation 'write-region) (stringp begin))
       nil
     (prog1
     (let ((buffer-default
